@@ -20,9 +20,6 @@ import (
 	"github.com/spf13/cobra"
 	vfs "github.com/twpayne/go-vfs/v4"
 	"golang.org/x/crypto/ripemd160" //nolint:staticcheck
-	"golang.org/x/exp/constraints"
-	"golang.org/x/exp/maps"
-	"golang.org/x/exp/slices"
 )
 
 var (
@@ -163,9 +160,7 @@ func FQDNHostname(fileSystem vfs.FS) (string, error) {
 }
 
 // FlagCompletionFunc returns a flag completion function.
-func FlagCompletionFunc(allCompletions []string) func(*cobra.Command, []string, string) (
-	[]string, cobra.ShellCompDirective,
-) {
+func FlagCompletionFunc(allCompletions []string) func(*cobra.Command, []string, string) ([]string, cobra.ShellCompDirective) {
 	return func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		var completions []string
 		for _, completion := range allCompletions {
@@ -204,9 +199,8 @@ func SuspiciousSourceDirEntry(base string, fileInfo fs.FileInfo, encryptedSuffix
 			return true
 		}
 		for _, encryptedSuffix := range encryptedSuffixes {
-			if fileAttr := parseFileAttr(fileInfo.Name(), encryptedSuffix); knownTargetFiles.contains(
-				fileAttr.TargetName,
-			) {
+			fileAttr := parseFileAttr(fileInfo.Name(), encryptedSuffix)
+			if knownTargetFiles.contains(fileAttr.TargetName) {
 				return true
 			}
 		}
@@ -363,13 +357,6 @@ func sha512Sum(data []byte) []byte {
 	return sha512SumArr[:]
 }
 
-// sortedKeys returns the keys of V in order.
-func sortedKeys[K constraints.Ordered, V any](m map[K]V) []K {
-	keys := maps.Keys(m)
-	slices.Sort(keys)
-	return keys
-}
-
 // ensureSuffix adds suffix to s if s is not suffixed by suffix.
 func ensureSuffix(s, suffix string) string {
 	if strings.HasSuffix(s, suffix) {
