@@ -48,32 +48,15 @@ func (c *Config) newAddCmd() *cobra.Command {
 		c.Add.autoTemplate,
 		"Generate the template when adding files as templates",
 	)
-	flags.BoolVar(
-		&c.Add.create,
-		"create",
-		c.Add.create,
-		"Add files that should exist, irrespective of their contents",
-	)
+	flags.BoolVar(&c.Add.create, "create", c.Add.create, "Add files that should exist, irrespective of their contents")
 	flags.BoolVar(&c.Add.encrypt, "encrypt", c.Add.encrypt, "Encrypt files")
 	flags.BoolVar(&c.Add.exact, "exact", c.Add.exact, "Add directories exactly")
 	flags.VarP(c.Add.filter.Exclude, "exclude", "x", "Exclude entry types")
-	flags.BoolVarP(
-		&c.Add.follow,
-		"follow",
-		"f",
-		c.Add.follow,
-		"Add symlink targets instead of symlinks",
-	)
+	flags.BoolVarP(&c.Add.follow, "follow", "f", c.Add.follow, "Add symlink targets instead of symlinks")
 	flags.VarP(c.Add.filter.Include, "include", "i", "Include entry types")
 	flags.BoolVarP(&c.Add.prompt, "prompt", "p", c.Add.prompt, "Prompt before adding each entry")
 	flags.BoolVarP(&c.Add.quiet, "quiet", "q", c.Add.quiet, "Suppress warnings")
-	flags.BoolVarP(
-		&c.Add.recursive,
-		"recursive",
-		"r",
-		c.Add.recursive,
-		"Recurse into subdirectories",
-	)
+	flags.BoolVarP(&c.Add.recursive, "recursive", "r", c.Add.recursive, "Recurse into subdirectories")
 	flags.BoolVarP(&c.Add.template, "template", "T", c.Add.template, "Add files as templates")
 	flags.BoolVar(
 		&c.Add.TemplateSymlinks,
@@ -148,11 +131,7 @@ func (c *Config) defaultReplaceFunc(
 		return nil
 	}
 	removedAttributesStr := englishListWithNoun(removedAttributes, "attribute", "")
-	prompt := fmt.Sprintf(
-		"adding %s would remove %s, continue",
-		targetRelPath,
-		removedAttributesStr,
-	)
+	prompt := fmt.Sprintf("adding %s would remove %s, continue", targetRelPath, removedAttributesStr)
 
 	for {
 		switch choice, err := c.promptChoice(prompt, choicesYesNoAllQuit); {
@@ -173,11 +152,7 @@ func (c *Config) defaultReplaceFunc(
 	}
 }
 
-func (c *Config) runAddCmd(
-	cmd *cobra.Command,
-	args []string,
-	sourceState *chezmoi.SourceState,
-) error {
+func (c *Config) runAddCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
 	destAbsPathInfos, err := c.destAbsPathInfos(sourceState, args, destAbsPathInfosOptions{
 		follow:    c.Mode == chezmoi.ModeSymlink || c.Add.follow,
 		recursive: c.Add.recursive,
