@@ -155,9 +155,7 @@ func example(command string) string {
 }
 
 // extractHelps returns the helps parse from r.
-func extractHelp(
-	command string, data []byte, longHelpTermRenderer, exampleTermRenderer *glamour.TermRenderer,
-) (*help, error) {
+func extractHelp(command string, data []byte, longHelpTermRenderer, exampleTermRenderer *glamour.TermRenderer) (*help, error) {
 	type stateType int
 	const (
 		stateReadTitle stateType = iota
@@ -300,9 +298,7 @@ func runMain(versionInfo VersionInfo, args []string) (err error) {
 		// Translate bbolt timeout errors into a friendlier message. As the
 		// persistent state is opened lazily, this error could occur at any
 		// time, so it's easiest to intercept it here.
-		err = errors.New(
-			"timeout obtaining persistent state lock, is another instance of chezmoi running?",
-		)
+		err = errors.New("timeout obtaining persistent state lock, is another instance of chezmoi running?")
 	}
 	return
 }
