@@ -346,11 +346,8 @@ func newConfig(options ...configOption) (*Config, error) {
 			filter:      chezmoi.NewEntryTypeFilter(chezmoi.EntryTypesAll, chezmoi.EntryTypesNone),
 		},
 		init: initCmdConfig{
-			data: true,
-			filter: chezmoi.NewEntryTypeFilter(
-				chezmoi.EntryTypesAll,
-				chezmoi.EntryTypesNone,
-			),
+			data:              true,
+			filter:            chezmoi.NewEntryTypeFilter(chezmoi.EntryTypesAll, chezmoi.EntryTypesNone),
 			guessRepoURL:      true,
 			recurseSubmodules: true,
 		},
@@ -633,9 +630,7 @@ func (c *Config) applyArgs(
 
 	keptGoingAfterErr := false
 	for _, targetRelPath := range targetRelPaths {
-		switch err := sourceState.Apply(
-			targetSystem, c.destSystem, c.persistentState, targetDirAbsPath, targetRelPath, applyOptions,
-		); {
+		switch err := sourceState.Apply(targetSystem, c.destSystem, c.persistentState, targetDirAbsPath, targetRelPath, applyOptions); {
 		case errors.Is(err, fs.SkipDir):
 			continue
 		case err != nil && c.keepGoing:
@@ -646,7 +641,7 @@ func (c *Config) applyArgs(
 		}
 	}
 
-	switch err := sourceState.PostApply(targetSystem, targetDirAbsPath, targetRelPaths); {
+	switch err := sourceState.PostApply(targetSystem, c.persistentState, targetDirAbsPath, targetRelPaths); {
 	case err != nil && c.keepGoing:
 		c.errorf("%v\n", err)
 		keptGoingAfterErr = true
@@ -734,11 +729,7 @@ func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
 		return c.persistentState.Delete(chezmoi.ConfigStateBucket, configStateKey)
 	}
 
-	configFileContents, err := c.createConfigFile(
-		configTemplate.targetRelPath,
-		configTemplate.contents,
-		cmd,
-	)
+	configFileContents, err := c.createConfigFile(configTemplate.targetRelPath, configTemplate.contents, cmd)
 	if err != nil {
 		return err
 	}
@@ -790,11 +781,7 @@ func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
 
 // createConfigFile creates a config file using a template and returns its
 // contents.
-func (c *Config) createConfigFile(
-	filename chezmoi.RelPath,
-	data []byte,
-	cmd *cobra.Command,
-) ([]byte, error) {
+func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte, cmd *cobra.Command) ([]byte, error) {
 	funcMap := make(template.FuncMap)
 	chezmoi.RecursiveMerge(funcMap, c.templateFuncs)
 	initTemplateFuncs := map[string]any{
@@ -828,10 +815,7 @@ func (c *Config) createConfigFile(
 
 // defaultConfigFile returns the default config file according to the XDG Base
 // Directory Specification.
-func (c *Config) defaultConfigFile(
-	fileSystem vfs.FS,
-	bds *xdg.BaseDirectorySpecification,
-) (chezmoi.AbsPath, error) {
+func (c *Config) defaultConfigFile(fileSystem vfs.FS, bds *xdg.BaseDirectorySpecification) (chezmoi.AbsPath, error) {
 	// Search XDG Base Directory Specification config directories first.
 CONFIG_DIR:
 	for _, configDir := range bds.ConfigDirs {
@@ -885,11 +869,7 @@ CONFIG_DIR:
 }
 
 // decodeConfigBytes decodes data in format into configFile.
-func (c *Config) decodeConfigBytes(
-	format chezmoi.Format,
-	data []byte,
-	configFile *ConfigFile,
-) error {
+func (c *Config) decodeConfigBytes(format chezmoi.Format, data []byte, configFile *ConfigFile) error {
 	var configMap map[string]any
 	if err := format.Unmarshal(data, &configMap); err != nil {
 		return err
@@ -984,11 +964,8 @@ func (c *Config) defaultPreApplyFunc(
 			case err != nil:
 				return err
 			case choice == "diff":
-				if err := c.diffFile(
-					targetRelPath,
-					actualContents, actualEntryState.Mode,
-					targetContents, targetEntryState.Mode,
-				); err != nil {
+				err := c.diffFile(targetRelPath, actualContents, actualEntryState.Mode, targetContents, targetEntryState.Mode)
+				if err != nil {
 					return err
 				}
 			case choice == "yes":
@@ -1030,11 +1007,7 @@ func (c *Config) defaultPreApplyFunc(
 		case err != nil:
 			return err
 		case choice == "diff":
-			if err := c.diffFile(
-				targetRelPath,
-				actualContents, actualEntryState.Mode,
-				targetContents, targetEntryState.Mode,
-			); err != nil {
+			if err := c.diffFile(targetRelPath, actualContents, actualEntryState.Mode, targetContents, targetEntryState.Mode); err != nil {
 				return err
 			}
 		case choice == "overwrite":
@@ -1054,10 +1027,7 @@ func (c *Config) defaultPreApplyFunc(
 
 // defaultSourceDir returns the default source directory according to the XDG
 // Base Directory Specification.
-func (c *Config) defaultSourceDir(
-	fileSystem vfs.Stater,
-	bds *xdg.BaseDirectorySpecification,
-) (chezmoi.AbsPath, error) {
+func (c *Config) defaultSourceDir(fileSystem vfs.Stater, bds *xdg.BaseDirectorySpecification) (chezmoi.AbsPath, error) {
 	// Check for XDG Base Directory Specification data directories first.
 	for _, dataDir := range bds.DataDirs {
 		dataDirAbsPath, err := chezmoi.NewAbsPathFromExtPath(dataDir, c.homeDirAbsPath)
@@ -1087,7 +1057,9 @@ type destAbsPathInfosOptions struct {
 // args, recursing into subdirectories and following symlinks if configured in
 // options.
 func (c *Config) destAbsPathInfos(
-	sourceState *chezmoi.SourceState, args []string, options destAbsPathInfosOptions,
+	sourceState *chezmoi.SourceState,
+	args []string,
+	options destAbsPathInfosOptions,
 ) (map[chezmoi.AbsPath]fs.FileInfo, error) {
 	destAbsPathInfos := make(map[chezmoi.AbsPath]fs.FileInfo)
 	for _, arg := range args {
@@ -1113,12 +1085,7 @@ func (c *Config) destAbsPathInfos(
 						return err
 					}
 				}
-				return sourceState.AddDestAbsPathInfos(
-					destAbsPathInfos,
-					c.destSystem,
-					destAbsPath,
-					fileInfo,
-				)
+				return sourceState.AddDestAbsPathInfos(destAbsPathInfos, c.destSystem, destAbsPath, fileInfo)
 			}
 			if err := chezmoi.Walk(c.destSystem, destAbsPath, walkFunc); err != nil {
 				return nil, err
@@ -1148,8 +1115,10 @@ func (c *Config) destAbsPathInfos(
 // at path.
 func (c *Config) diffFile(
 	path chezmoi.RelPath,
-	fromData []byte, fromMode fs.FileMode,
-	toData []byte, toMode fs.FileMode,
+	fromData []byte,
+	fromMode fs.FileMode,
+	toData []byte,
+	toMode fs.FileMode,
 ) error {
 	builder := strings.Builder{}
 	unifiedEncoder := diff.NewUnifiedEncoder(&builder, diff.DefaultContextLines)
@@ -1192,11 +1161,7 @@ func (c *Config) editor(args []string) (string, []string, error) {
 	}
 
 	// Prefer $VISUAL over $EDITOR and fallback to the OS's default editor.
-	editCommand = firstNonEmptyString(
-		os.Getenv("VISUAL"),
-		os.Getenv("EDITOR"),
-		defaultEditor,
-	)
+	editCommand = firstNonEmptyString(os.Getenv("VISUAL"), os.Getenv("EDITOR"), defaultEditor)
 
 	return parseCommand(editCommand, append(editArgs, args...))
 }
@@ -1312,10 +1277,7 @@ func (c *Config) findConfigTemplate() (*configTemplate, error) {
 			sourceAbsPathStr := configTemplate.sourceAbsPath.String()
 			sourceAbsPathStrs = append(sourceAbsPathStrs, sourceAbsPathStr)
 		}
-		return nil, fmt.Errorf(
-			"multiple config file templates: %s ",
-			englishList(sourceAbsPathStrs),
-		)
+		return nil, fmt.Errorf("multiple config file templates: %s ", englishList(sourceAbsPathStrs))
 	}
 }
 
@@ -1399,10 +1361,7 @@ func (c *Config) getSourceDirAbsPath(options *getSourceDirAbsPathOptions) (chezm
 	return c.sourceDirAbsPath, c.sourceDirAbsPathErr
 }
 
-func (c *Config) getSourceState(
-	ctx context.Context,
-	cmd *cobra.Command,
-) (*chezmoi.SourceState, error) {
+func (c *Config) getSourceState(ctx context.Context, cmd *cobra.Command) (*chezmoi.SourceState, error) {
 	if c.sourceState != nil || c.sourceStateErr != nil {
 		return c.sourceState, c.sourceStateErr
 	}
@@ -1457,11 +1416,7 @@ func (c *Config) gitAutoAdd() (*git.Status, error) {
 	if err := c.run(c.WorkingTreeAbsPath, c.Git.Command, []string{"add", "."}); err != nil {
 		return nil, err
 	}
-	output, err := c.cmdOutput(
-		c.WorkingTreeAbsPath,
-		c.Git.Command,
-		[]string{"status", "--porcelain=v2"},
-	)
+	output, err := c.cmdOutput(c.WorkingTreeAbsPath, c.Git.Command, []string{"status", "--porcelain=v2"})
 	if err != nil {
 		return nil, err
 	}
@@ -1478,11 +1433,7 @@ func (c *Config) gitAutoCommit(cmd *cobra.Command, status *git.Status) error {
 	if err != nil {
 		return err
 	}
-	return c.run(
-		c.WorkingTreeAbsPath,
-		c.Git.Command,
-		[]string{"commit", "--message", string(commitMessage)},
-	)
+	return c.run(c.WorkingTreeAbsPath, c.Git.Command, []string{"commit", "--message", string(commitMessage)})
 }
 
 // gitAutoPush pushes all changes to the remote if status is not empty.
@@ -1517,9 +1468,7 @@ func (c *Config) gitCommitMessage(cmd *cobra.Command, status *git.Status) ([]byt
 		if c.sourceDirAbsPathErr != nil {
 			return nil, c.sourceDirAbsPathErr
 		}
-		commitMessageTemplateFileAbsPath := c.sourceDirAbsPath.JoinString(
-			c.Git.CommitMessageTemplateFile,
-		)
+		commitMessageTemplateFileAbsPath := c.sourceDirAbsPath.JoinString(c.Git.CommitMessageTemplateFile)
 		name = c.sourceDirAbsPath.String()
 		var err error
 		commitMessageTemplateData, err = c.baseSystem.ReadFile(commitMessageTemplateFileAbsPath)
@@ -1530,14 +1479,9 @@ func (c *Config) gitCommitMessage(cmd *cobra.Command, status *git.Status) ([]byt
 		name = "COMMIT_MESSAGE"
 		commitMessageTemplateData = []byte(templates.CommitMessageTmpl)
 	}
-	commitMessageTmpl, err := chezmoi.ParseTemplate(
-		name,
-		commitMessageTemplateData,
-		funcMap,
-		chezmoi.TemplateOptions{
-			Options: slices.Clone(c.Template.Options),
-		},
-	)
+	commitMessageTmpl, err := chezmoi.ParseTemplate(name, commitMessageTemplateData, funcMap, chezmoi.TemplateOptions{
+		Options: slices.Clone(c.Template.Options),
+	})
 	if err != nil {
 		return nil, err
 	}
@@ -1604,33 +1548,16 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.Var(&c.configFormat, "config-format", "Set config file format")
 	persistentFlags.Var(&c.cpuProfile, "cpu-profile", "Write a CPU profile to path")
 	persistentFlags.BoolVar(&c.debug, "debug", c.debug, "Include debug information in output")
-	persistentFlags.BoolVarP(
-		&c.dryRun,
-		"dry-run",
-		"n",
-		c.dryRun,
-		"Do not make any modifications to the destination directory",
-	)
+	persistentFlags.BoolVarP(&c.dryRun, "dry-run", "n", c.dryRun, "Do not make any modifications to the destination directory")
 	persistentFlags.BoolVar(&c.force, "force", c.force, "Make all changes without prompting")
 	persistentFlags.BoolVar(&c.interactive, "interactive", c.interactive, "Prompt for all changes")
-	persistentFlags.BoolVarP(
-		&c.keepGoing,
-		"keep-going",
-		"k",
-		c.keepGoing,
-		"Keep going as far as possible after an error",
-	)
+	persistentFlags.BoolVarP(&c.keepGoing, "keep-going", "k", c.keepGoing, "Keep going as far as possible after an error")
 	persistentFlags.BoolVar(&c.noPager, "no-pager", c.noPager, "Do not use the pager")
 	persistentFlags.BoolVar(&c.noTTY, "no-tty", c.noTTY, "Do not attempt to get a TTY for prompts")
 	persistentFlags.VarP(&c.outputAbsPath, "output", "o", "Write output to path instead of stdout")
 	persistentFlags.VarP(&c.refreshExternals, "refresh-externals", "R", "Refresh external cache")
 	persistentFlags.Lookup("refresh-externals").NoOptDefVal = chezmoi.RefreshExternalsAlways.String()
-	persistentFlags.BoolVar(
-		&c.sourcePath,
-		"source-path",
-		c.sourcePath,
-		"Specify targets by source path",
-	)
+	persistentFlags.BoolVar(&c.sourcePath, "source-path", c.sourcePath, "Specify targets by source path")
 
 	if err := chezmoierrors.Combine(
 		rootCmd.MarkPersistentFlagFilename("config"),
@@ -1708,18 +1635,11 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 
 // newDiffSystem returns a system that logs all changes to s to w using
 // diff.command if set or the builtin git diff otherwise.
-func (c *Config) newDiffSystem(
-	s chezmoi.System,
-	w io.Writer,
-	dirAbsPath chezmoi.AbsPath,
-) chezmoi.System {
+func (c *Config) newDiffSystem(s chezmoi.System, w io.Writer, dirAbsPath chezmoi.AbsPath) chezmoi.System {
 	if c.Diff.useBuiltinDiff || c.Diff.Command == "" {
 		options := &chezmoi.GitDiffSystemOptions{
-			Color: c.Color.Value(c.colorAutoFunc),
-			Filter: chezmoi.NewEntryTypeFilter(
-				c.Diff.include.Bits(),
-				c.Diff.Exclude.Bits(),
-			),
+			Color:          c.Color.Value(c.colorAutoFunc),
+			Filter:         chezmoi.NewEntryTypeFilter(c.Diff.include.Bits(), c.Diff.Exclude.Bits()),
 			Reverse:        c.Diff.Reverse,
 			ScriptContents: c.Diff.ScriptContents,
 			TextConvFunc:   c.TextConv.convert,
@@ -1736,7 +1656,9 @@ func (c *Config) newDiffSystem(
 
 // newSourceState returns a new SourceState with options.
 func (c *Config) newSourceState(
-	ctx context.Context, cmd *cobra.Command, options ...chezmoi.SourceStateOption,
+	ctx context.Context,
+	cmd *cobra.Command,
+	options ...chezmoi.SourceStateOption,
 ) (*chezmoi.SourceState, error) {
 	if err := c.checkVersion(); err != nil {
 		return nil, err
@@ -1806,8 +1728,10 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 		if err := c.diffPagerCmdStdin.Close(); err != nil {
 			return err
 		}
-		if err := chezmoilog.LogCmdWait(c.diffPagerCmd); err != nil {
-			return err
+		if c.diffPagerCmd.Process != nil {
+			if err := chezmoilog.LogCmdWait(c.diffPagerCmd); err != nil {
+				return err
+			}
 		}
 	}
 
@@ -1908,9 +1832,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 
 	if runtime.GOOS == "windows" {
 		var err error
-		c.restoreWindowsConsole, err = termenv.EnableVirtualTerminalProcessing(
-			termenv.DefaultOutput(),
-		)
+		c.restoreWindowsConsole, err = termenv.EnableVirtualTerminalProcessing(termenv.DefaultOutput())
 		if err != nil {
 			return err
 		}
@@ -1996,7 +1918,9 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 			return err
 		}
 		c.persistentState, err = chezmoi.NewBoltPersistentState(
-			c.baseSystem, persistentStateFileAbsPath, chezmoi.BoltPersistentStateReadOnly,
+			c.baseSystem,
+			persistentStateFileAbsPath,
+			chezmoi.BoltPersistentStateReadOnly,
 		)
 		if err != nil {
 			return err
@@ -2009,7 +1933,9 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 			return err
 		}
 		persistentState, err := chezmoi.NewBoltPersistentState(
-			c.baseSystem, persistentStateFileAbsPath, chezmoi.BoltPersistentStateReadOnly,
+			c.baseSystem,
+			persistentStateFileAbsPath,
+			chezmoi.BoltPersistentStateReadOnly,
 		)
 		if err != nil {
 			return err
@@ -2028,7 +1954,9 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 			return err
 		}
 		c.persistentState, err = chezmoi.NewBoltPersistentState(
-			c.baseSystem, persistentStateFileAbsPath, chezmoi.BoltPersistentStateReadWrite,
+			c.baseSystem,
+			persistentStateFileAbsPath,
+			chezmoi.BoltPersistentStateReadWrite,
 		)
 		if err != nil {
 			return err
@@ -2040,10 +1968,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		persistentStateLogger := c.logger.With().
 			Str(logComponentKey, logComponentValuePersistentState).
 			Logger()
-		c.persistentState = chezmoi.NewDebugPersistentState(
-			c.persistentState,
-			&persistentStateLogger,
-		)
+		c.persistentState = chezmoi.NewDebugPersistentState(c.persistentState, &persistentStateLogger)
 	}
 
 	// Set up the source and destination systems.
@@ -2073,12 +1998,15 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		default:
 			pipeReader, pipeWriter := io.Pipe()
 			pagerCmd.Stdin = pipeReader
-			if err := chezmoilog.LogCmdStart(pagerCmd); err != nil {
-				return err
-			}
-			writer = pipeWriter
+			lazyWriter := newLazyWriter(func() (io.WriteCloser, error) {
+				if err := chezmoilog.LogCmdStart(pagerCmd); err != nil {
+					return nil, err
+				}
+				return pipeWriter, nil
+			})
+			writer = lazyWriter
 			c.diffPagerCmd = pagerCmd
-			c.diffPagerCmdStdin = pipeWriter
+			c.diffPagerCmdStdin = lazyWriter
 		}
 		c.sourceSystem = c.newDiffSystem(c.sourceSystem, writer, c.SourceDirAbsPath)
 		c.destSystem = c.newDiffSystem(c.destSystem, writer, c.DestDirAbsPath)
@@ -2410,11 +2338,7 @@ func (c *Config) runEditor(args []string) error {
 	err = c.run(chezmoi.EmptyAbsPath, editor, editorArgs)
 	if runtime.GOOS != "windows" && c.Edit.MinDuration != 0 {
 		if duration := time.Since(start); duration < c.Edit.MinDuration {
-			c.errorf(
-				"warning: %s: returned in less than %s\n",
-				shellQuoteCommand(editor, editorArgs),
-				c.Edit.MinDuration,
-			)
+			c.errorf("warning: %s: returned in less than %s\n", shellQuoteCommand(editor, editorArgs), c.Edit.MinDuration)
 		}
 	}
 	return err
@@ -2500,10 +2424,7 @@ func (c *Config) setEnvironmentVariables() error {
 
 // sourceAbsPaths returns the source absolute paths for each target path in
 // args.
-func (c *Config) sourceAbsPaths(
-	sourceState *chezmoi.SourceState,
-	args []string,
-) ([]chezmoi.AbsPath, error) {
+func (c *Config) sourceAbsPaths(sourceState *chezmoi.SourceState, args []string) ([]chezmoi.AbsPath, error) {
 	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
 		mustBeInSourceState: true,
 		mustBeManaged:       true,
@@ -2513,9 +2434,7 @@ func (c *Config) sourceAbsPaths(
 	}
 	sourceAbsPaths := make([]chezmoi.AbsPath, 0, len(targetRelPaths))
 	for _, targetRelPath := range targetRelPaths {
-		sourceAbsPath := c.SourceDirAbsPath.Join(
-			sourceState.MustEntry(targetRelPath).SourceRelPath().RelPath(),
-		)
+		sourceAbsPath := c.SourceDirAbsPath.Join(sourceState.MustEntry(targetRelPath).SourceRelPath().RelPath())
 		sourceAbsPaths = append(sourceAbsPaths, sourceAbsPath)
 	}
 	return sourceAbsPaths, nil
@@ -2524,11 +2443,7 @@ func (c *Config) sourceAbsPaths(
 func (c *Config) targetRelPath(absPath chezmoi.AbsPath) (chezmoi.RelPath, error) {
 	relPath, err := absPath.TrimDirPrefix(c.DestDirAbsPath)
 	if notInAbsDirError := (&chezmoi.NotInAbsDirError{}); errors.As(err, &notInAbsDirError) {
-		return chezmoi.EmptyRelPath, fmt.Errorf(
-			"%s: not in destination directory (%s)",
-			absPath,
-			c.DestDirAbsPath,
-		)
+		return chezmoi.EmptyRelPath, fmt.Errorf("%s: not in destination directory (%s)", absPath, c.DestDirAbsPath)
 	}
 	return relPath, err
 }
@@ -2542,7 +2457,9 @@ type targetRelPathsOptions struct {
 // targetRelPaths returns the target relative paths for each target path in
 // args. The returned paths are sorted and de-duplicated.
 func (c *Config) targetRelPaths(
-	sourceState *chezmoi.SourceState, args []string, options targetRelPathsOptions,
+	sourceState *chezmoi.SourceState,
+	args []string,
+	options targetRelPathsOptions,
 ) (chezmoi.RelPaths, error) {
 	targetRelPaths := make(chezmoi.RelPaths, 0, len(args))
 	for _, arg := range args {
@@ -2594,9 +2511,7 @@ func (c *Config) targetRelPaths(
 
 // targetRelPathsBySourcePath returns the target relative paths for each arg in
 // args.
-func (c *Config) targetRelPathsBySourcePath(
-	sourceState *chezmoi.SourceState, args []string,
-) ([]chezmoi.RelPath, error) {
+func (c *Config) targetRelPathsBySourcePath(sourceState *chezmoi.SourceState, args []string) ([]chezmoi.RelPath, error) {
 	targetRelPaths := make([]chezmoi.RelPath, 0, len(args))
 	targetRelPathsBySourceRelPath := make(map[chezmoi.RelPath]chezmoi.RelPath)
 	_ = sourceState.ForEach(
@@ -2625,9 +2540,7 @@ func (c *Config) targetRelPathsBySourcePath(
 }
 
 // targetValidArgs returns target completions for toComplete given args.
-func (c *Config) targetValidArgs(
-	cmd *cobra.Command, args []string, toComplete string,
-) ([]string, cobra.ShellCompDirective) {
+func (c *Config) targetValidArgs(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	if !c.Completion.Custom {
 		return nil, cobra.ShellCompDirectiveDefault
 	}
@@ -2840,11 +2753,8 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 		Update: updateCmdConfig{
 			RecurseSubmodules: true,
 			apply:             true,
-			filter: chezmoi.NewEntryTypeFilter(
-				chezmoi.EntryTypesAll,
-				chezmoi.EntryTypesNone,
-			),
-			recursive: true,
+			filter:            chezmoi.NewEntryTypeFilter(chezmoi.EntryTypesAll, chezmoi.EntryTypesNone),
+			recursive:         true,
 		},
 		Verify: verifyCmdConfig{
 			Exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
