@@ -53,11 +53,8 @@ const (
 
 // A check is an individual check.
 type check interface {
-	Name() string // Name returns the check's name.
-	Run(
-		system chezmoi.System,
-		homeDirAbsPath chezmoi.AbsPath,
-	) (checkResult, string) // Run runs the check.
+	Name() string                                                                    // Name returns the check's name.
+	Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) // Run runs the check.
 }
 
 var checkResultStr = map[checkResult]string{
@@ -433,13 +430,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 		// output of chezmoi doctor is often posted publicly and would otherwise
 		// reveal the user's username.
 		message = strings.ReplaceAll(message, homeDirAbsPath.String(), "~")
-		fmt.Fprintf(
-			resultWriter,
-			"%s\t%s\t%s\n",
-			checkResultStr[checkResult],
-			check.Name(),
-			message,
-		)
+		fmt.Fprintf(resultWriter, "%s\t%s\t%s\n", checkResultStr[checkResult], check.Name(), message)
 		if checkResult > worstResult {
 			worstResult = checkResult
 		}
@@ -457,10 +448,7 @@ func (c *argsCheck) Name() string {
 	return c.name
 }
 
-func (c *argsCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *argsCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	return checkResultOK, shellQuoteCommand(c.command, c.args)
 }
 
@@ -468,10 +456,7 @@ func (c *binaryCheck) Name() string {
 	return c.name
 }
 
-func (c *binaryCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *binaryCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	if c.binaryname == "" {
 		return c.ifNotSet, "not set"
 	}
@@ -503,11 +488,7 @@ func (c *binaryCheck) Run(
 	if c.versionRx != nil {
 		match := c.versionRx.FindSubmatch(versionBytes)
 		if len(match) != 2 {
-			s := fmt.Sprintf(
-				"found %s, cannot parse version from %s",
-				pathAbsPath,
-				bytes.TrimSpace(versionBytes),
-			)
+			s := fmt.Sprintf("found %s, cannot parse version from %s", pathAbsPath, bytes.TrimSpace(versionBytes))
 			return checkResultWarning, s
 		}
 		versionBytes = match[1]
@@ -518,12 +499,7 @@ func (c *binaryCheck) Run(
 	}
 
 	if c.minVersion != nil && version.LessThan(*c.minVersion) {
-		return checkResultError, fmt.Sprintf(
-			"found %s, version %s, need %s",
-			pathAbsPath,
-			version,
-			c.minVersion,
-		)
+		return checkResultError, fmt.Sprintf("found %s, version %s, need %s", pathAbsPath, version, c.minVersion)
 	}
 
 	return checkResultOK, fmt.Sprintf("found %s, version %s", pathAbsPath, version)
@@ -533,10 +509,7 @@ func (c *configFileCheck) Name() string {
 	return "config-file"
 }
 
-func (c *configFileCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *configFileCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	filenameAbsPaths := make(map[chezmoi.AbsPath]struct{})
 	for _, dir := range append([]string{c.bds.ConfigHome}, c.bds.ConfigDirs...) {
 		configDirAbsPath, err := chezmoi.NewAbsPathFromExtPath(dir, homeDirAbsPath)
@@ -544,10 +517,7 @@ func (c *configFileCheck) Run(
 			return checkResultFailed, err.Error()
 		}
 		for _, extension := range chezmoi.FormatExtensions {
-			filenameAbsPath := configDirAbsPath.Join(
-				c.basename,
-				chezmoi.NewRelPath(c.basename.String()+"."+extension),
-			)
+			filenameAbsPath := configDirAbsPath.Join(c.basename, chezmoi.NewRelPath(c.basename.String()+"."+extension))
 			if _, err := system.Stat(filenameAbsPath); err == nil {
 				filenameAbsPaths[filenameAbsPath] = struct{}{}
 			}
@@ -559,11 +529,7 @@ func (c *configFileCheck) Run(
 	case 1:
 		filenameAbsPath := anyKey(filenameAbsPaths)
 		if filenameAbsPath != c.expected {
-			return checkResultFailed, fmt.Sprintf(
-				"found %s, expected %s",
-				filenameAbsPath,
-				c.expected,
-			)
+			return checkResultFailed, fmt.Sprintf("found %s, expected %s", filenameAbsPath, c.expected)
 		}
 		config, err := newConfig()
 		if err != nil {
@@ -576,11 +542,7 @@ func (c *configFileCheck) Run(
 		if err != nil {
 			return checkResultError, fmt.Sprintf("%s: %v", filenameAbsPath, err)
 		}
-		message := fmt.Sprintf(
-			"%s, last modified %s",
-			filenameAbsPath.String(),
-			fileInfo.ModTime().Format(time.RFC3339),
-		)
+		message := fmt.Sprintf("%s, last modified %s", filenameAbsPath.String(), fileInfo.ModTime().Format(time.RFC3339))
 		return checkResultOK, message
 	default:
 		filenameStrs := make([]string, 0, len(filenameAbsPaths))
@@ -588,10 +550,7 @@ func (c *configFileCheck) Run(
 			filenameStrs = append(filenameStrs, filenameAbsPath.String())
 		}
 		sort.Strings(filenameStrs)
-		return checkResultWarning, fmt.Sprintf(
-			"%s: multiple config files",
-			englishList(filenameStrs),
-		)
+		return checkResultWarning, fmt.Sprintf("%s: multiple config files", englishList(filenameStrs))
 	}
 }
 
@@ -599,10 +558,7 @@ func (c *dirCheck) Name() string {
 	return c.name
 }
 
-func (c *dirCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *dirCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	dirEntries, err := system.ReadDir(c.dirname)
 	if err != nil {
 		return checkResultError, err.Error()
@@ -653,10 +609,7 @@ func (executableCheck) Name() string {
 	return "executable"
 }
 
-func (executableCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (executableCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	executable, err := os.Executable()
 	if err != nil {
 		return checkResultError, err.Error()
@@ -672,10 +625,7 @@ func (c *fileCheck) Name() string {
 	return c.name
 }
 
-func (c *fileCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *fileCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	if c.filename.Empty() {
 		return c.ifNotSet, "not set"
 	}
@@ -694,10 +644,7 @@ func (goVersionCheck) Name() string {
 	return "go-version"
 }
 
-func (goVersionCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (goVersionCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	return checkResultOK, fmt.Sprintf("%s (%s)", runtime.Version(), runtime.Compiler)
 }
 
@@ -705,10 +652,7 @@ func (c *latestVersionCheck) Name() string {
 	return "latest-version"
 }
 
-func (c *latestVersionCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *latestVersionCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	if c.httpClientErr != nil {
 		return checkResultFailed, c.httpClientErr.Error()
 	}
@@ -746,10 +690,7 @@ func (osArchCheck) Name() string {
 	return "os-arch"
 }
 
-func (osArchCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (osArchCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	fields := []string{runtime.GOOS + "/" + runtime.GOARCH}
 	if osRelease, err := chezmoi.OSRelease(system.UnderlyingFS()); err == nil {
 		if name, ok := osRelease["NAME"].(string); ok {
@@ -767,10 +708,7 @@ func (skippedCheck) Name() string {
 	return "skipped"
 }
 
-func (skippedCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (skippedCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	return checkResultSkipped, ""
 }
 
@@ -778,10 +716,7 @@ func (c *suspiciousEntriesCheck) Name() string {
 	return "suspicious-entries"
 }
 
-func (c *suspiciousEntriesCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *suspiciousEntriesCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	// FIXME include user-defined suffixes from age and gpg configs
 	encryptedSuffixes := []string{
 		defaultAgeEncryptionConfig.Suffix,
@@ -814,10 +749,7 @@ func (upgradeMethodCheck) Name() string {
 	return "upgrade-method"
 }
 
-func (upgradeMethodCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (upgradeMethodCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	executable, err := os.Executable()
 	if err != nil {
 		return checkResultFailed, err.Error()
@@ -836,10 +768,7 @@ func (c *versionCheck) Name() string {
 	return "version"
 }
 
-func (c *versionCheck) Run(
-	system chezmoi.System,
-	homeDirAbsPath chezmoi.AbsPath,
-) (checkResult, string) {
+func (c *versionCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	if c.versionInfo.Version == "" || c.versionInfo.Commit == "" {
 		return checkResultWarning, c.versionStr
 	}
