@@ -44,13 +44,8 @@ func (c *Config) keepassxcAttachmentTemplateFunc(entry, name string) string {
 		panic(err)
 	}
 	if version.Compare(keepassxcHasAttachmentExportVersion) < 0 {
-		panic(
-			fmt.Sprintf(
-				"keepassxc-cli version %s required, found %s",
-				keepassxcHasAttachmentExportVersion,
-				version,
-			),
-		)
+		format := "keepassxc-cli version %s required, found %s"
+		panic(fmt.Sprintf(format, keepassxcHasAttachmentExportVersion, version))
 	}
 
 	if data, ok := c.Keepassxc.attachmentCache[entry][name]; ok {
@@ -142,9 +137,7 @@ func (c *Config) keepassxcOutput(name string, args []string) ([]byte, error) {
 
 	cmd := exec.Command(name, args...)
 	if c.Keepassxc.password == "" && c.Keepassxc.Prompt {
-		password, err := c.readPassword(
-			fmt.Sprintf("Insert password to unlock %s: ", c.Keepassxc.Database),
-		)
+		password, err := c.readPassword(fmt.Sprintf("Insert password to unlock %s: ", c.Keepassxc.Database))
 		if err != nil {
 			return nil, err
 		}
