@@ -36,11 +36,7 @@ func (c *Config) newMergeCmd() *cobra.Command {
 	return mergeCmd
 }
 
-func (c *Config) runMergeCmd(
-	cmd *cobra.Command,
-	args []string,
-	sourceState *chezmoi.SourceState,
-) error {
+func (c *Config) runMergeCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
 	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
 		mustBeInSourceState: true,
 		mustBeManaged:       false,
@@ -63,10 +59,7 @@ func (c *Config) runMergeCmd(
 // doMerge is the core merge functionality. It invokes the merge tool to do a
 // three-way merge between the destination, source, and target, including
 // transparently decrypting the file in the source state.
-func (c *Config) doMerge(
-	targetRelPath chezmoi.RelPath,
-	sourceStateEntry chezmoi.SourceStateEntry,
-) (err error) {
+func (c *Config) doMerge(targetRelPath chezmoi.RelPath, sourceStateEntry chezmoi.SourceStateEntry) (err error) {
 	sourceAbsPath := c.SourceDirAbsPath.Join(sourceStateEntry.SourceRelPath().RelPath())
 
 	// If the source state entry is an encrypted file, then decrypt it to a
@@ -79,9 +72,7 @@ func (c *Config) doMerge(
 			if plaintextTempDirAbsPath, err = c.tempDir("chezmoi-merge-plaintext"); err != nil {
 				return
 			}
-			plaintextAbsPath = plaintextTempDirAbsPath.Join(
-				sourceStateEntry.SourceRelPath().RelPath(),
-			)
+			plaintextAbsPath = plaintextTempDirAbsPath.Join(sourceStateEntry.SourceRelPath().RelPath())
 			defer chezmoierrors.CombineFunc(&err, func() error {
 				return os.RemoveAll(plaintextTempDirAbsPath.String())
 			})
@@ -104,9 +95,7 @@ func (c *Config) doMerge(
 	// two-way merge if the source state's contents cannot be decrypted or
 	// are an invalid template
 	var targetStateEntry chezmoi.TargetStateEntry
-	if targetStateEntry, err = sourceStateEntry.TargetStateEntry(
-		c.destSystem, c.DestDirAbsPath.Join(targetRelPath),
-	); err != nil {
+	if targetStateEntry, err = sourceStateEntry.TargetStateEntry(c.destSystem, c.DestDirAbsPath.Join(targetRelPath)); err != nil {
 		err = fmt.Errorf("%s: %w", targetRelPath, err)
 		return
 	}
@@ -197,9 +186,7 @@ func (c *Config) doMerge(
 		if encryptedContents, err = c.encryption.EncryptFile(plaintextAbsPath); err != nil {
 			return
 		}
-		if err = c.baseSystem.WriteFile(
-			c.SourceDirAbsPath.Join(sourceStateEntry.SourceRelPath().RelPath()), encryptedContents, 0o644,
-		); err != nil {
+		if err = c.baseSystem.WriteFile(c.SourceDirAbsPath.Join(sourceStateEntry.SourceRelPath().RelPath()), encryptedContents, 0o644); err != nil {
 			return
 		}
 	}
