@@ -41,11 +41,7 @@ func (c *Config) newReAddCmd() *cobra.Command {
 	return reAddCmd
 }
 
-func (c *Config) runReAddCmd(
-	cmd *cobra.Command,
-	args []string,
-	sourceState *chezmoi.SourceState,
-) error {
+func (c *Config) runReAddCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
 	var targetRelPaths chezmoi.RelPaths
 	sourceStateEntries := make(map[chezmoi.RelPath]chezmoi.SourceStateEntry)
 	if len(args) == 0 {
@@ -131,11 +127,7 @@ TARGET_REL_PATH:
 				case err != nil:
 					return err
 				case choice == "diff":
-					if err := c.diffFile(
-						targetRelPath,
-						targetContents, targetStateFile.Perm(c.Umask),
-						actualContents, actualStateFile.Perm(),
-					); err != nil {
+					if err := c.diffFile(targetRelPath, targetContents, targetStateFile.Perm(c.Umask), actualContents, actualStateFile.Perm()); err != nil {
 						return err
 					}
 				case choice == "yes":
