@@ -62,12 +62,7 @@ func (c *Config) newUpgradeCmd() *cobra.Command {
 	}
 
 	flags := upgradeCmd.Flags()
-	flags.StringVar(
-		&c.upgrade.executable,
-		"executable",
-		c.upgrade.method,
-		"Set executable to replace",
-	)
+	flags.StringVar(&c.upgrade.executable, "executable", c.upgrade.method, "Set executable to replace")
 	flags.StringVar(&c.upgrade.method, "method", c.upgrade.method, "Set upgrade method")
 	flags.StringVar(&c.upgrade.owner, "owner", c.upgrade.owner, "Set owner")
 	flags.StringVar(&c.upgrade.repo, "repo", c.upgrade.repo, "Set repo")
@@ -81,9 +76,7 @@ func (c *Config) runUpgradeCmd(cmd *cobra.Command, args []string) error {
 
 	var zeroVersion semver.Version
 	if c.version == zeroVersion && !c.force {
-		return errors.New(
-			"cannot upgrade dev version to latest released version unless --force is set",
-		)
+		return errors.New("cannot upgrade dev version to latest released version unless --force is set")
 	}
 
 	httpClient, err := c.getHTTPClient()
@@ -125,12 +118,7 @@ func (c *Config) runUpgradeCmd(cmd *cobra.Command, args []string) error {
 		case err != nil:
 			return err
 		case method == "":
-			return fmt.Errorf(
-				"%s/%s: cannot determine upgrade method for %s",
-				runtime.GOOS,
-				runtime.GOARCH,
-				executableAbsPath,
-			)
+			return fmt.Errorf("%s/%s: cannot determine upgrade method for %s", runtime.GOOS, runtime.GOARCH, executableAbsPath)
 		}
 	}
 	c.logger.Info().
@@ -188,15 +176,8 @@ func (c *Config) runUpgradeCmd(cmd *cobra.Command, args []string) error {
 	return chezmoilog.LogCmdRun(chezmoiVersionCmd)
 }
 
-func (c *Config) getChecksums(
-	ctx context.Context,
-	rr *github.RepositoryRelease,
-) (map[string][]byte, error) {
-	name := fmt.Sprintf(
-		"%s_%s_checksums.txt",
-		c.upgrade.repo,
-		strings.TrimPrefix(rr.GetTagName(), "v"),
-	)
+func (c *Config) getChecksums(ctx context.Context, rr *github.RepositoryRelease) (map[string][]byte, error) {
+	name := fmt.Sprintf("%s_%s_checksums.txt", c.upgrade.repo, strings.TrimPrefix(rr.GetTagName(), "v"))
 	releaseAsset := getReleaseAssetByName(rr, name)
 	if releaseAsset == nil {
 		return nil, fmt.Errorf("%s: cannot find release asset", name)
@@ -247,7 +228,9 @@ func (c *Config) downloadURL(ctx context.Context, url string) ([]byte, error) {
 }
 
 func (c *Config) replaceExecutable(
-	ctx context.Context, executableFilenameAbsPath chezmoi.AbsPath, releaseVersion *semver.Version,
+	ctx context.Context,
+	executableFilenameAbsPath chezmoi.AbsPath,
+	releaseVersion *semver.Version,
 	rr *github.RepositoryRelease,
 ) (err error) {
 	var archiveFormat chezmoi.ArchiveFormat
@@ -259,40 +242,16 @@ func (c *Config) replaceExecutable(
 		if libc, err = getLibc(); err != nil {
 			return
 		}
-		archiveName = fmt.Sprintf(
-			"%s_%s_%s-%s_%s.tar.gz",
-			c.upgrade.repo,
-			releaseVersion,
-			runtime.GOOS,
-			libc,
-			runtime.GOARCH,
-		)
+		archiveName = fmt.Sprintf("%s_%s_%s-%s_%s.tar.gz", c.upgrade.repo, releaseVersion, runtime.GOOS, libc, runtime.GOARCH)
 	case runtime.GOOS == "linux" && runtime.GOARCH == "386":
 		archiveFormat = chezmoi.ArchiveFormatTarGz
-		archiveName = fmt.Sprintf(
-			"%s_%s_%s_i386.tar.gz",
-			c.upgrade.repo,
-			releaseVersion,
-			runtime.GOOS,
-		)
+		archiveName = fmt.Sprintf("%s_%s_%s_i386.tar.gz", c.upgrade.repo, releaseVersion, runtime.GOOS)
 	case runtime.GOOS == "windows":
 		archiveFormat = chezmoi.ArchiveFormatZip
-		archiveName = fmt.Sprintf(
-			"%s_%s_%s_%s.zip",
-			c.upgrade.repo,
-			releaseVersion,
-			runtime.GOOS,
-			runtime.GOARCH,
-		)
+		archiveName = fmt.Sprintf("%s_%s_%s_%s.zip", c.upgrade.repo, releaseVersion, runtime.GOOS, runtime.GOARCH)
 	default:
 		archiveFormat = chezmoi.ArchiveFormatTarGz
-		archiveName = fmt.Sprintf(
-			"%s_%s_%s_%s.tar.gz",
-			c.upgrade.repo,
-			releaseVersion,
-			runtime.GOOS,
-			runtime.GOARCH,
-		)
+		archiveName = fmt.Sprintf("%s_%s_%s_%s.tar.gz", c.upgrade.repo, releaseVersion, runtime.GOOS, runtime.GOARCH)
 	}
 	releaseAsset := getReleaseAssetByName(rr, archiveName)
 	if releaseAsset == nil {
@@ -344,12 +303,7 @@ func (c *Config) replaceExecutable(
 	return
 }
 
-func (c *Config) verifyChecksum(
-	ctx context.Context,
-	rr *github.RepositoryRelease,
-	name string,
-	data []byte,
-) error {
+func (c *Config) verifyChecksum(ctx context.Context, rr *github.RepositoryRelease, name string, data []byte) error {
 	checksums, err := c.getChecksums(ctx, rr)
 	if err != nil {
 		return err
@@ -360,12 +314,8 @@ func (c *Config) verifyChecksum(
 	}
 	checksum := sha256.Sum256(data)
 	if !bytes.Equal(checksum[:], expectedChecksum) {
-		return fmt.Errorf(
-			"%s: checksum failed (want %s, got %s)",
-			name,
-			hex.EncodeToString(expectedChecksum),
-			hex.EncodeToString(checksum[:]),
-		)
+		format := "%s: checksum failed (want %s, got %s)"
+		return fmt.Errorf(format, name, hex.EncodeToString(expectedChecksum), hex.EncodeToString(checksum[:]))
 	}
 	return nil
 }
